@@ -8,5 +8,5 @@ import Language.Haskell.TH
 $( do TyConI (DataD _ _ [KindedTV tvb_a _ _] _ _ _) <- reify ''Maybe
       my_a <- newName "a"
       return [TySynD (mkName "SMaybe")
-                     [KindedTV my_a () (AppT (ConT ''Maybe) (VarT tvb_a))]
+                     [KindedTV my_a BndrReq (AppT (ConT ''Maybe) (VarT tvb_a))]
                      (TupleT 0)] )
